from ..third_party.abc import ABCMeta, abstractmethod


class BaseHandler():
    @abstractmethod
    def initPara(self): pass

    @abstractmethod
    def initOpener(self, conf): pass

    @abstractmethod
    def getUrlList(self, conf): pass



import argparse

from utils import *
from crawlercore import CrawlerManager


availableModule = [
    "gamersky",
    "pixiv",
]


def printHelp(parser):
    parser.print_help()
    print ""
    print "available plugins:"
    for module in availableModule:
        print "----" + module


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('plugin', help='plugin the crawler uses')
    if len(sys.argv) < 2:
        printHelp(parser)
        sys.exit(0)

    if sys.argv[1] == "-h" or sys.argv[1] == "--help":
        printHelp(parser)
        sys.exit(0)

    pluginName = sys.argv[1]
    try:
        module = dynamicImport("crawl_me.plugin." + pluginName)
    except Exception, e:
        syslog(str(e), LOG_DEBUG)
        syslog("moudle not found! moudleName:%s" % (pluginName), LOG_ERROR)
        printHelp(parser)
        sys.exit(-1)

    class_ = getattr(module, pluginName[0].upper() + pluginName[1:] + "Handler")
    plugin = class_()
    conf = plugin.initPara(parser)
    opener = plugin.initOpener(conf)
    urlList = plugin.getUrlList(conf)
    syslog("total pictures to crawl:%s" % (len(urlList)))
    manager = CrawlerManager(opener, urlList, conf["savePath"], conf["useRangeHeaders"])
    manager.startCrawl()



PROJECT_METADATA = "project.json"

import json, os, codecs
here = os.path.abspath(os.path.dirname(__file__))
proj_conf = json.loads(open(os.path.join(here, PROJECT_METADATA)).read())

long_description = proj_conf["description"]
if os.path.exists("README.txt") and os.path.exists("CHANGELOG.txt"):
    README = codecs.open(os.path.join(here, 'README.txt'), "r", "utf8").read()
    CHANGELOG = codecs.open(os.path.join(here, 'CHANGELOG.txt'), "r", "utf8").read()
    long_description = README + "\n\n" + CHANGELOG

from setuptools import setup, find_packages

setup(
    name = proj_conf["name"],
    version = proj_conf["version"],

    packages = find_packages(),
    install_requires = ['pyquery>=1.2.5'],

    author = proj_conf["author"],
    author_email = proj_conf["author_email"],
    url = proj_conf["url"],
    license = proj_conf["license"],

    description = proj_conf["description"],
    classifiers = proj_conf["classifiers"],
    keywords = proj_conf["keywords"],

    long_description = long_description,

    platforms = 'any',
    include_package_data = True,

    entry_points = {
        'console_scripts': proj_conf["console_scripts"]
    }
)
